@@ -1,5 +1,5 @@
-#ifndef __MON_SYS_CALL_H__
-#define __MON_SYS_CALL_H__
+#ifndef __EXPORTS_H__
+#define __EXPORTS_H__
 
 #ifndef __ASSEMBLY__
 
@@ -20,10 +20,20 @@ void udelay(unsigned long);
 unsigned long get_timer(unsigned long);
 void vprintf(const char *, va_list);
 void do_reset (void);
-#if (CONFIG_COMMANDS & CFG_CMD_I2C)
+unsigned long simple_strtoul(const char *cp,char **endp,unsigned int base);
+char *getenv (char *name);
+int setenv (char *varname, char *varvalue);
+long simple_strtol(const char *cp,char **endp,unsigned int base);
+int strcmp(const char * cs,const char * ct);
+int ustrtoul(const char *cp, char **endp, unsigned int base);
+#ifdef CONFIG_HAS_UID
+void forceenv (char *varname, char *varvalue);
+#endif
+#if defined(CONFIG_CMD_I2C)
 int i2c_write (uchar, uint, int , uchar* , int);
 int i2c_read (uchar, uint, int , uchar* , int);
-#endif	/* CFG_CMD_I2C */
+#endif
+#include <spi.h>
 
 void app_startup(char **);
 
@@ -37,10 +47,10 @@ enum {
 	XF_MAX
 };
 
-#define XF_VERSION	2
+#define XF_VERSION	6
 
 #if defined(CONFIG_I386)
 extern gd_t *global_data;
 #endif
 
-#endif
+#endif	/* __EXPORTS_H__ */
